diff --git a/.github/workflows/ci.yaml b/.github/workflows/ci.yaml
index 35bef5d..847eaa9 100644
--- a/.github/workflows/ci.yaml
+++ b/.github/workflows/ci.yaml
@@ -74,7 +74,7 @@ jobs:
- name: Run cargo test
uses: actions-rs/cargo@v1
env:
- AXIOM_URL: ${{ secrets.TESTING_DEV_APP_URL }}
+ AXIOM_URL: ${{ secrets.TESTING_DEV_API_URL }}
AXIOM_TOKEN: ${{ secrets.TESTING_DEV_TOKEN }}
AXIOM_ORG_ID: ${{ secrets.TESTING_DEV_ORG_ID }}
AXIOM_DATASET_SUFFIX: ${{ github.run_id }}
diff --git a/README.md b/README.md
index 6ea7276..5e971a9 100644
--- a/README.md
+++ b/README.md
@@ -4,7 +4,7 @@
[](https://docs.rs/axiom-rs/)
-[](https://github.com/axiomhq/axiom-rs/actions?query=workflow%3ACI)
+[](https://github.com/axiomhq/axiom-rs/actions?query=workflow%3ACI)
[](https://crates.io/crates/axiom-rs)
[](LICENSE-APACHE)
diff --git a/src/http.rs b/src/http.rs
index 0f99b35..58b4799 100644
--- a/src/http.rs
+++ b/src/http.rs
@@ -42,10 +42,7 @@ impl Client {
T: Into,
O: Into
diff --git a/src/client.rs b/src/client.rs
index 7505106..da16073 100644
--- a/src/client.rs
+++ b/src/client.rs
@@ -25,8 +25,8 @@ use crate::{
is_personal_token, users,
};
-/// Cloud URL is the URL for Axiom Cloud.
-static CLOUD_URL: &str = "https://cloud.axiom.co";
+/// API URL is the URL for the Axiom Cloud API.
+static API_URL: &str = "https://api.axiom.co";
/// The client is the entrypoint of the whole SDK.
///
@@ -71,7 +71,7 @@ impl Client {
Builder::new()
}
/// Get the url (cloned).
#[doc(hidden)]
pub fn url(&self) -> String {
self.url.clone()
@@ -351,7 +351,7 @@ impl Builder {
url = env::var("AXIOM_URL").unwrap_or_default();
}
if url.is_empty() {
- url = CLOUD_URL.to_string();
+ url = API_URL.to_string();
}
let mut org_id = self.org_id.unwrap_or_default();
@@ -360,7 +360,7 @@ impl Builder {
};
// On Cloud you need an Org ID for Personal Tokens.
- if url == CLOUD_URL && org_id.is_empty() && is_personal_token(&token) {
+ if url == API_URL && org_id.is_empty() && is_personal_token(&token) {
return Err(Error::MissingOrgId);
}
@@ -71,7 +71,7 @@ impl Client {
Builder::new()
}
- /// Get the url (cloned).
+ /// Get the API url (cloned).
#[doc(hidden)]
pub fn url(&self) -> String {